// git-remote-k8s - a git remote helper to use PVCs as a remote
// Copyright (C) 2023  James Andariese
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

use crate::*;

#[derive(ThisError, Debug)]
pub enum ApplicationError {
    /// cluster state problems
    #[error("cluster is in an inconsistent state")]
    RemoteClusterInconsistent,

    /// pod state problems
    #[error("pod metadata doesn't contain a name")]
    PodNoName,
    #[error("pod metadata doesn't contain a namespace")]
    PodNoNamespace,
    #[error("couldn't open pod's stdin")]
    PodCouldNotOpenStdin,
    #[error("couldn't open pod's stdout")]
    PodCouldNotOpenStdout,
    #[error("couldn't open pod's stderr")]
    PodCouldNotOpenStderr,
    #[error("pod failed to start")]
    PodCouldNotStart,
    #[error("worker pod did not continue running")]
    PodDidNotWait,
}

#[derive(ThisError, Debug)]
pub enum ConfigError {
    #[error("no namespace present in remote URL")]
    RemoteNoNamespace,
    #[error("trailing elements after pvc in remote URL")]
    RemoteTrailingElements,
    #[error("no context present in remote URL")]
    RemoteNoContext,
    #[error("no PVC name present in remote URL")]
    RemoteNoPVC,
    #[error("invalid remote URL")]
    RemoteInvalid,
    #[error("remote URL has an invalid (or no) scheme")]
    RemoteInvalidScheme,
}
